IncrByFloat

Struct IncrByFloat 

pub struct IncrByFloat {
    pub key: String,
    pub increment: f64,
}
Increment the string representing a floating point number stored at key by the specified increment. By using a negative increment value, the result is that the value stored at the key is decremented (by the obvious properties of addition). If the key does not exist, it is set to 0 before performing the operation.

Ref: https://redis.io/docs/latest/commands/incrbyfloat/

TODO:

  • Handle overflow errors.
  • The precision of the output is fixed at 17 digits after the decimal point regardless of the actual internal precision of the computation.
  • Both the value already contained in the string key and the increment argument can be optionally provided in exponential notation.

Fields

key: Stringincrement: f64